<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.27
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Admin\Library;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Libs\Registry;

abstract class Templates
{
    /**
     * Add or remove favorites
     * 
     * @param   int  $template_id
     * 
     * @return  void
     */
    public function addOrRemoveFavorite($template_id)
    {
        $favorites = $this->getFavorites();

        if (array_key_exists($template_id, $favorites))
        {  
            $this->removeFromFavorites($template_id);
            return;
        }
        
        $this->addToFavorites($template_id);
    }

    /**
     * Add to favorites
     * 
     * @param   int  $template_id
     * 
     * @return  void
     */
    public function addToFavorites($template_id)
    {
        $favorites = $this->getFavorites();

        if (array_key_exists($template_id, $favorites))
        {  
            return;
        }

        $favorites[$template_id] = true;

        $this->saveFavorites($favorites);
    }

    /**
     * Save favorites to file
     * 
     * @param   string  $content
     * 
     * @return  void
     */
    public function saveFavorites($content)
    {
        $file = $this->getPath() . 'favorites.json';

        return file_put_contents($file, json_encode($content));
    }

    /**
     * Remove from favorites
     * 
     * @param   int  $template_id
     * 
     * @return  void
     */
    public function removeFromFavorites($template_id)
    {
        $favorites = $this->getFavorites();
        unset($favorites[$template_id]);
        $this->saveFavorites($favorites);
    }

    /**
     * Get favorites
     *  
     * @return  array
     */
    public function getFavorites()
    {
        $file = $this->getPath() . 'favorites.json';

        if (!file_exists($file))
        {
            return [];
        }
        
        return (array) json_decode(file_get_contents($file), true);
    }

    /**
     * Get templates list
     * 
     * @return  array
     */
    public function getList()
    {
		// try to find local templates with fallback remote templates
        return $this->getLocalTemplates() ?: $this->getRemoteTemplatesAndStore();
    }

    /**
     * Save templates locally
     * 
     * @param   array  $body
     * 
     * @return  void
     */
    private function saveLocalTemplate($body)
    {
        $path = $this->getPath() . 'templates.json';
        
        file_put_contents($path, json_encode($body));
    }

    /**
     * Returns the local templates
     * 
     * @return  array
     */
	private function getLocalTemplates()
	{
        $path = $this->getPath() . 'templates.json';
        
		if (!file_exists($path))
		{
			return false;
        }

		return json_decode(file_get_contents($path));
	}

    /**
     * Returns the remote templates
     * 
     * @return  array
     */
	private function getRemoteTemplates()
	{
        $license = get_option($this->library_settings['plugin'] . '_license_key');
		$site_url = preg_replace('(^https?://)', '', get_site_url());
        $site_url = rtrim($site_url, '/') . '/';
        
        // get remote templates
		$templates_url = str_replace('{{PLUGIN}}', $this->library_settings['plugin'], FPF_TEMPLATES_GET_URL);
		$templates_url = str_replace('{{LICENSE_KEY}}', $license, $templates_url);
		$templates_url = str_replace('{{SITE_URL}}', $site_url, $templates_url);
        
        $response = wp_remote_get($templates_url);

        if ( !is_array( $response ) || \is_wp_error( $response ) )
        {
            return $response;
        }
        else
        {
            $body = json_decode($response['body']);

            // an error has occurred
            if (isset($body->error))
            {
                return $body->error;
            }
            
            return $body;
        }
    }
    
    /**
     * Gets the remote templates and stores them locally
     * 
     * @return  array
     */
    public function getRemoteTemplatesAndStore()
    {
        $templates = $this->getRemoteTemplates();

        if (!$templates)
        {
            return new \WP_Error('cannot_retrieve_templates', fpframework()->_('FPF_TEMPLATES_CANNOT_BE_RETRIEVED'));
        }

        // return errors
        if (isset($templates->code) || \is_wp_error($templates))
        {
            return $templates;
        }
        
        $this->saveLocalTemplate($templates);

        return $templates;
    }

    /**
     * Find template data from list
     * 
     * @param   string  $template_alias
     * 
     * @return  void
     */
    public function find($template_alias)
    {
        if (!$templates = $this->getList())
        {
            return;
        }

        foreach ($templates as $group)
        {
            foreach ($group as $tmpl)
            {
                if ($tmpl->alias != $template_alias)
                {
                    continue;
                }
            
                if (!isset($tmpl->template->item_data))
                {
                    return [];
                }

                $item = $tmpl->template->item_data;
                $item->custom_fields = $tmpl->fields;

                // check if we have meta data as well
                if (isset($tmpl->template->meta))
                {
                    $params = $tmpl->template->meta;
                    $item->params = (array) $params;
                }

                return $item;
            }
        }
    }

    /**
     * Return templates folder path
     *  
     * @return  string
     */
    public function getPath()
    {
        return $this->library_settings['plugin_dir'] . 'media/admin/templates/';
    }
}