<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.27
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Helpers;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class WPHelper
{
    /**
     * Returns WPML data needed to get the locale for each post
     * 
     * @param   string  $item
     * @param   string  $join_clause
     * 
     * @return  array
     */
    public static function getWPMLQueryData($item = 'p.ID', $join_clause = PostsBaseHelper::join_clause)
    {
		if (!class_exists('SitePress'))
		{
            return [];
        }

        global $wpdb;

        $locale = get_locale();
        $lang_explode = explode('_', $locale);

        $select = ',iclt.language_code as lang';
        $join = "LEFT JOIN {$wpdb->prefix}icl_translations as iclt ON iclt.element_id = {$item} {$join_clause}";

        return [
            'select' => $select,
            'join' => $join,
            'lang_code' => $lang_explode[0]
        ];
    }

    /**
     * Retives the WPML Flag image from country code
     * 
     * @param   string   $code
     * 
     * @return  string
     */
    public static function getWPMLFlagUrlFromCode($code)
    {
        if (!class_exists('SitePress'))
        {
            return '';
        }

        if (empty($code))
        {
            return '';
        }
        
        global $wpdb;
        $wpml_flags = new \WPML_Flags( $wpdb, new \icl_cache( 'flags', true ), new \WP_Filesystem_Direct( null ) );

        // Prepare country code
        switch (strtolower($code))
        {
            // Sweden
            case 'se':
                $code = 'sv';
                break;
            // Estonia
            case 'ee':
                $code = 'et';
                break;
            // Malaysia
            case 'my':
                $code = 'ms';
                break;
            // Serbia
            case 'rs':
                $code = 'sr';
                break;
            // Slovenia
            case 'si':
                $code = 'sl';
                break;
            // Ukraine
            case 'ua':
                $code = 'uk';
                break;
        }
        
        $suffix = strtolower($code) . '.png';
        
        if (!file_exists($wpml_flags->get_wpml_flags_directory() . $suffix))
        {
            return '';
        }

        return '<img src="' . esc_url($wpml_flags->get_wpml_flags_url() . $suffix) . '" style="width:18px;height:12px;" alt="' . esc_attr($code) . ' flag" />';
    }

	/**
	 * Returns the current page ID
	 * 
	 * @return  mixed
	 */
	public static function getPageID()
	{
        if (!is_front_page() && is_home())
        {
            return (int) get_option('page_for_posts');
        }
        
        global $wp_query;
        $current_object_id = $wp_query->post;

        if (!$current_object_id)
        {
            return null;
        }

        return (int) $current_object_id->ID;
    }
    
	/**
	 * Checks and returns the active plugins from the a list of plugin names.
	 * 
	 * @param   array  $plugins
	 * 
	 * @return  array
	 */
	public static function getActivePluginsFromList($plugins)
	{
		if (!$plugins)
		{
			return [];
		}

		if (!is_array($plugins))
		{
			return [];
		}

		$active = [];

		foreach ($plugins as $key => $value)
		{
			if (!self::isPluginActive($key))
			{
				continue;
			}

			$active[$key] = $value;
		}
		
		return $active;
    }
    
    /**
     * Checks whether a plugin is active via its plugin name.
     * 
     * @param   string   $plugin_name
     * 
     * @return  boolean
     */
    public static function isPluginActive($plugin_name)
    {
        if (!$plugin_name || !is_string($plugin_name))
        {
            return false;
        }

        $plugin = $plugin_name . '/' . $plugin_name . '.php';
            
        return \is_plugin_active($plugin);
    }

    /**
     * Checks if the Classic Editor plugin is active.
     *
     * @return  bool
     */
    public static function isClassicEditorPluginActive()
    {
        if (!function_exists('is_plugin_active'))
        {
            include_once ABSPATH . 'wp-admin/includes/plugin.php';
        }

        if (is_plugin_active('classic-editor/classic-editor.php'))
        {
            return true;
        }

        return false;
    }

    /**
     * Returns all allowed HTML tags used when printing output HTML.
     * 
     * @return  array
     */
    public static function getAllowedHTMLTags()
    {
        $allowed_tags = wp_kses_allowed_html('post');

        // Form
        $allowed_tags['form'] = [
            'action'         => true,
            'accept'         => true,
            'accept-charset' => true,
            'enctype'        => true,
            'method'         => true,
            'name'           => true,
            'target'         => true,
            'role'           => true,
            'data-*'         => true
        ];

        // SVG
        $allowed_tags['svg'] = [
            'class'           => true,
            'aria-hidden'     => true,
            'aria-labelledby' => true,
            'role'            => true,
            'xmlns'           => true,
            'width'           => true,
            'height'          => true,
            'fill'            => true,
            'viewbox'         => true
        ];
        $allowed_tags['mask'] = [
            'id' => true,
            'fill' => true,
        ];
        $allowed_tags['line'] = [
            'x1' => true,
            'x2' => true,
            'y1' => true,
            'y2' => true,
            'stroke' => true,
            'stroke-width' => true,
            'stroke-linecap' => true,
            'stroke-join' => true,
        ];
        $allowed_tags['circle'] = [
            'cx' => true,
            'cy' => true,
            'r' => true,
            'stroke' => true,
            'stroke-width' => true,
            'opacity' => true,
            'width' => true,
            'height' => true,
            'fill' => true,
        ];
        $allowed_tags['rect'] = [
            'x' => true,
            'y' => true,
            'transform' => true,
            'opacity' => true,
            'width' => true,
            'height' => true,
            'stroke' => true,
            'stroke-width' => true,
            'rx' => true,
            'fill' => true,
            'mask' => true,
        ];
        $allowed_tags['g'] = [
            'fill' => true
        ];
        $allowed_tags['title'] = [
            'title' => true
        ];
        $allowed_tags['path'] = [
            'd'                 => true,
            'stroke'            => true,
            'stroke-width'      => true,
            'stroke-linecap'    => true,
            'stroke-linejoin'   => true,
            'fill'              => true
        ];

        // Input
        $allowed_tags['input'] = [
            'class'       => true,
            'id'          => true,
            'name'        => true,
            'value'       => true,
            'type'        => true,
            'placeholder' => true,
            'checked'     => true,
            'data-*'      => true
        ];

        // Select
        $allowed_tags['select'] = [
            'class'     => true,
            'id'        => true,
            'name'      => true,
            'value'     => true,
            'type'      => true,
            'data-*'    => true
        ];

        // Select option
        $allowed_tags['option'] = [
            'selected'  => true,
            'name'      => true,
            'value'     => true,
            'class'     => true,
            'data-*'    => true
        ];

        // Style
        $allowed_tags['style'] = [
            'types' => true,
        ];

        // i element
        $allowed_tags['i'] = [
            'class' => true,
        ];

        // Script
        $allowed_tags['script'] = true;

        return $allowed_tags;
    }
}