<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.27
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Libs;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class Translations
{
	/**
	 * Holds all translations of the framework and the current plugin.
	 * 
	 * @var  array
	 */
	private $translations;

	/**
	 * All provided paths to each plugin's Translation class.
	 * If a translation is not found in Framework, then we search
	 * for it in this list of paths. Each translation string
	 * contains a prefix at the start which is used to identify the
	 * correct Translation class to use and search for the translation.
	 * 
	 * Path format:
	 * [
	 * 		'global_pluginname_method' => [
	 * 			'prefix' => 'PREFIX_'
	 * 		]
	 * ]
	 */
	private $paths = [];
	
	public function __construct()
	{
		$this->translations = $this->getTranslations();
		$this->translations = apply_filters('fpframework/set_translations', $this->translations);
		$this->paths = apply_filters('fpframework/set_translation_paths', $this->paths);
	}

	/**
	 * Retrieves the translation of $text
	 * 
	 * @param  String  $text
	 * @param  String  $fallback
	 * 
	 * @return  String
	 */
	public function _($text, $fallback = null)
	{
		if (!is_string($text) && !is_int($text))
		{
			return '';
		}

		if (empty($text))
		{
			return '';
		}
		
		$translation = $this->retrieve($text, $fallback);

		if ($translation)
		{
			return $translation;
		}

		// if no paths given and no translation is found, return fallback
		if (!count($this->paths))
		{
			return $fallback ? trim($fallback) : trim($text);
		}

		// get translation prefix
		$prefix_data = explode('_', $text);
		$prefix = $prefix_data[0];

		// loop through all paths and find translation
		foreach ($this->paths as $key => $path)
		{
			// ensure we use the Translation class with the correct prefix
			if (!$prefix = $path['prefix'])
			{
				continue;
			}

			// translation string must start with prefix
			if (!(strpos($text, $prefix) === 0))
			{
				continue;
			}

			// a function must exist from the plugin with the name of the prefix
			if (!function_exists($key))
			{
				continue;
			}
			
			if (!$translation = $key()->translations->retrieve($text, $fallback))
			{
				continue;
			}
			
			return $translation;
		}
		
		return $fallback ? trim($fallback) : trim($text);
	}

	/**
	 * Retrieves translation of given text or of fallback text.
	 * If none found, returns false
	 * 
	 * @param   string  $text
	 * @param   string  $fallback
	 * 
	 * @return  mixed
	 */
	private function retrieve($text, $fallback)
	{
		if (!is_string($text) && !is_numeric($text))
		{
			return '';
		}

		$fallback = !empty($fallback) ? $fallback : $text;

		if ($translationOfText = $this->findText($text))
		{
			return $translationOfText;
		}

		if ($translationOfFallback = $this->findText($fallback))
		{
			return $translationOfFallback;
		}

		return false;
	}

	/**
	 * Tries to find translation of text. Returns false if fails.
	 * 
	 * @param   string  $text
	 * 
	 * @return  mixed
	 */
	private function findText($text)
	{
		return isset($this->translations[strtoupper(trim($text))]) ? $this->translations[strtoupper(trim($text))] : false;
	}

	/**
	 * All Translations
	 * 
	 * @return array
	 */
	public static function getTranslations()
	{
		return [
			'FPF_NAME' => 'FirePlugins',
			'FPF_DOMAIN' => 'Fireplugins.com',
			'FPF_DASHBOARD' => __('Dashboard', 'fpf-framework'),
			'FPF_DOCUMENTATION' => __('Documentation', 'fpf-framework'),
			'FPF_FIREBOX' => __('FireBox', 'fpf-framework'),
			'FPF_FIRESCHEMA' => __('FireSchema', 'fpf-framework'),
			'FPF_FIREFORMS' => __('FireForms', 'fpf-framework'),
			'FPF_DOCS' => __('Docs', 'fpf-framework'),
			'FPF_NEW' => __('New', 'fpf-framework'),
			'FPF_HELP' => __('Help', 'fpf-framework'),
			'FPF_ID' => __('ID', 'fpf-framework'),
			'FPF_PUBLISHING_RULES' => __('Publishing Rules', 'fpf-framework'),
			'FPF_MODE' => __('Mode', 'fpf-framework'),
			'FPF_IMPORT' => __('Import', 'fpf-framework'),
			'FPF_SETTINGS' => __('Settings', 'fpf-framework'),
			'FPF_DISABLED' => __('Disabled', 'fpf-framework'),
			'FPF_INCLUDE' => __('Include', 'fpf-framework'),
			'FPF_EXCLUDE' => __('Exclude', 'fpf-framework'),
			'FPF_ENABLED' => __('Enabled', 'fpf-framework'),
			'FPF_SESSION' => __('Session', 'fpf-framework'),
			'FPF_ONCE_PER_SESSION' => __('Once Per Session', 'fpf-framework'),
			'FPF_ONCE_PER_DAY' => __('Once Per Day', 'fpf-framework'),
			'FPF_ONCE_PER_WEEK' => __('Once Per Week', 'fpf-framework'),
			'FPF_PER_SESSION' => __('Per Session', 'fpf-framework'),
			'FPF_PER_DAY' => __('Per Day', 'fpf-framework'),
			'FPF_PER_WEEK' => __('Per Week', 'fpf-framework'),
			'FPF_PER_MONTH' => __('Per Month', 'fpf-framework'),
			'FPF_FOREVER' => __('Forever', 'fpf-framework'),
			'FPF_IMPRESSIONS' => __('Impressions', 'fpf-framework'),
			'FPF_WIDTH' => __('Width', 'fpf-framework'),
			'FPF_HEIGHT' => __('Height', 'fpf-framework'),
			'FPF_PADDING' => __('Padding', 'fpf-framework'),
			'FPF_MARGIN' => __('Margin', 'fpf-framework'),
			'FPF_COLOR' => __('Color', 'fpf-framework'),
			'FPF_TEXT_COLOR' => __('Text Color', 'fpf-framework'),
			'FPF_BG_COLOR' => __('Background Color', 'fpf-framework'),
			'FPF_NONE' => __('None', 'fpf-framework'),
			'FPF_BORDER' => __('Border', 'fpf-framework'),
			'FPF_BORDER_DESC' => __('Set the border style, color, width and radius.', 'fpf-framework'),
			'FPF_STYLE' => __('Style', 'fpf-framework'),
			'FPF_SOLID' => __('Solid', 'fpf-framework'),
			'FPF_DOTTED' => __('Dotted', 'fpf-framework'),
			'FPF_DOUBLE' => __('Double', 'fpf-framework'),
			'FPF_DASHED' => __('Dashed', 'fpf-framework'),
			'FPF_INSET' => __('Inset', 'fpf-framework'),
			'FPF_OUTSET' => __('Outset', 'fpf-framework'),
			'FPF_GROOVE' => __('Groove', 'fpf-framework'),
			'FPF_RIDGE' => __('Ridge', 'fpf-framework'),
			'FPF_HIDDEN' => __('Hidden', 'fpf-framework'),
			'FPF_HIDE' => __('Hide', 'fpf-framework'),
			'FPF_ENABLED' => __('Enabled', 'fpf-framework'),
			'FPF_ICON' => __('Icon', 'fpf-framework'),
			'FPF_IMAGE' => __('Image', 'fpf-framework'),
			'FPF_BG_IMAGE' => __('Background Image', 'fpf-framework'),
			'FPF_BG_IMAGE_DESC' => __('Set the background image settings, repeat, size and position.', 'fpf-framework'),
			'FPF_REPEAT' => __('Repeat', 'fpf-framework'),
			'FPF_SIZE' => __('Size', 'fpf-framework'),
			'FPF_AUTO' => __('Auto', 'fpf-framework'),
			'FPF_POSITION' => __('Position', 'fpf-framework'),
			'FPF_FONT_SIZE' => __('Font Size', 'fpf-framework'),
			'FPF_FONT_SIZE_DESC' => __('Choose a font size in pixels.', 'fpf-framework'),
			'FPF_SELECT_IMAGE' => __('Select Image', 'fpf-framework'),
			'FPF_ALL' => __('All', 'fpf-framework'),
			'FPF_ANY' => __('Any', 'fpf-framework'),
			'FPF_WORDPRESS_CONTENT' => __('WordPress Content', 'fpf-framework'),
			'FPF_WORDPRESS_CONTENT_DESC' => __('Target specific posts, pages, categories, etc...', 'fpf-framework'),
			'FPF_POST' => __('Post', 'fpf-framework'),
			'FPF_PAGE' => __('Page', 'fpf-framework'),
			'FPF_PAGES' => __('Pages', 'fpf-framework'),
			'FPF_CPT' => __('Custom Post Type', 'fpf-framework'),
			'FPF_CPTS' => __('Custom Post Types', 'fpf-framework'),
			'FPF_POST_TAG' => __('Post Tag', 'fpf-framework'),
			'FPF_TAGS' => __('Tags', 'fpf-framework'),
			'FPF_POST_CATEGORY' => __('Post Category', 'fpf-framework'),
			'FPF_CATEGORIES' => __('Categories', 'fpf-framework'),
			'FPF_ADVANCED' => __('Advanced', 'fpf-framework'),
			'FPF_PA_ADVANCED' => __('Advanced visitor targeting', 'fpf-framework'),
			'FPF_CUSTOM_CODE' => __('Custom Code', 'fpf-framework'),
			'FPF_CUSTOM_CODE_DESC' => __('Enter your own Custom CSS & JavaScript in this section.', 'fpf-framework'),
			'FPF_CUSTOM_JAVASCRIPT' => __('Custom JavaScript', 'fpf-framework'),
			'FPF_CUSTOM_JAVASCRIPT_DESC' => __('Write your own custom JavaScript code (You don\'t need to enter the &lt;script&gt;&lt;/script&gt; tags).', 'fpf-framework'),
			'FPF_CUSTOM_CSS' => __('Custom CSS', 'fpf-framework'),
			'FPF_CUSTOM_CSS_DESC' => __('Write your own custom CSS Code (You don\'t need to enter the &lt;style&gt;&lt;/style&gt; tags).', 'fpf-framework'),
			'FPF_USE_GLOBAL' => __('Use Global', 'fpf-framework'),
			'FPF_YES' => __('Yes', 'fpf-framework'),
			'FPF_NO' => __('No', 'fpf-framework'),
			'FPF_ONLY' => __('Only', 'fpf-framework'),
			'FPF_CLASS_SUFFIX' => __('Class Suffix', 'fpf-framework'),
			'FPF_CLASS_SUFFIX_DESC' => __('Enter a class suffix.', 'fpf-framework'),
			'FPF_ALL_RIGHTS_RESERVED' => __('All Rights Reserved', 'fpf-framework'),
			'FPF_NEED_SUPPORT' => __('Need support?', 'fpf-framework'),
			'FPF_SUPPORT' => __('Support', 'fpf-framework'),
			'FPF_READ_THE_DOCS' => __('Read the Documentation', 'fpf-framework'),
			'FPF_OR' => __('or', 'fpf-framework'),
			'FPF_DROP_EMAIL' => __('Drop me an e-mail', 'fpf-framework'),
			'FPF_UPLOAD' => __('Upload', 'fpf-framework'),
			'FPF_PREVIEW' => __('Preview', 'fpf-framework'),
			'FPF_MEDIA_UPLOAD_TMP_IMG_ALT' => __('media uploader preview image', 'fpf-framework'),
			'FPF_ENSURE_PLUGIN_FOLDER_IS_READABLE' => __('Please make sure that the plugins folder is readable.', 'fpf-framework'),
			'FPF_PA_MENU_ITEM_AS' => __('Menu Item', 'fpf-framework'),
			'FPF_PA_MENU_ITEM_AS_DESC' => __('Target visitors who are browsing specific menu items', 'fpf-framework'),
			'FPF_PA_DATETIME' => __('Datetime', 'fpf-framework'),
			'FPF_PA_DATETIME_DESC' => __('Target visitors based on your server\'s datetime', 'fpf-framework'),
			'FPF_SELECTION' => __('Selection', 'fpf-framework'),
			'FPF_PA_ASSIGN_MENU_CHILD' => __('Also on child items', 'fpf-framework'),
			'FPF_PA_ASSIGN_MENU_CHILD_DESC' => __('Also assign to child items of the selected items?', 'fpf-framework'),
			'FPF_URL' => __('URL', 'fpf-framework'),
			'FPF_PA_URL_DESC' => __('Target visitors who are browsing specific URLs', 'fpf-framework'),
			'FPF_PA_URL_MATCHES' => __('URL Matches', 'fpf-framework'),
			'FPF_PA_URL_MATCHES_DESC' => __('Enter (part of) the URLs to match.<br />Use a new line for each different match.', 'fpf-framework'),
			'FPF_PA_REGUAL_EXPRESSION' => __('Use Regular Expression', 'fpf-framework'),
			'FPF_PA_REGUAL_EXPRESSION_DESC' => __('Select to treat the value as regular expressions.', 'fpf-framework'),
			'FPF_PA_MENU_ITEM_HINT' => __('Start searching for menu items.', 'fpf-framework'),
			'FPF_DATETIME_START' => __('Start Datetime', 'fpf-framework'),
			'FPF_DATETIME_START_DESC' => __('Enter the date to start publishing', 'fpf-framework'),
			'FPF_DATETIME_END' => __('End Datetime', 'fpf-framework'),
			'FPF_DATETIME_END_DESC' => __('Enter the date to end publishing', 'fpf-framework'),
			'FPF_PA_TIMERANGE' => __('Time Range', 'fpf-framework'),
			'FPF_PA_TIMERANGE_DESC' => __('Target visitors based on your server\'s time', 'fpf-framework'),
			'FPF_TIMEPICKER_START' => __('Start Time', 'fpf-framework'),
			'FPF_TIMEPICKER_START_DESC' => __('Enter the time to start publishing', 'fpf-framework'),
			'FPF_TIMEPICKER_END' => __('End Time', 'fpf-framework'),
			'FPF_TIMEPICKER_END_DESC' => __('Enter the time to end publishing', 'fpf-framework'),
			'FPF_USER_ROLE' => __('User Role', 'fpf-framework'),
			'FPF_USER_ROLE_DESC' => __('Target specific WordPress user roles', 'fpf-framework'),
			'FPF_USER_ROLE_AS_DESC' => __('Select the User Roles to assign to.', 'fpf-framework'),
			'FPF_PA_PAGE_URL_AS_DESC' => __('Select menu items.', 'fpf-framework'),
			'FPF_USER_ID' => __('User ID', 'fpf-framework'),
			'FPF_USER_ID_DESC' => __('Target specific WordPress Users by their IDs', 'fpf-framework'),
			'FPF_NUMBER_PAGEVIEWS' => __('Number of Pageviews', 'fpf-framework'),
			'FPF_NUMBER_PAGEVIEWS_DESC' => __('Target visitors who have viewed certain number of pages', 'fpf-framework'),
			'FPF_EXACTLY' => __('Exactly', 'fpf-framework'),
			'FPF_FEWER' => __('Fewer', 'fpf-framework'),
			'FPF_GREATER' => __('Greater', 'fpf-framework'),
			'FPF_MATCH' => __('Match', 'fpf-framework'),
			'FPF_PAGEVIEWS' => __('Pageviews', 'fpf-framework'),
			'FPF_TIMEONSITE' => __('Time on Site', 'fpf-framework'),
			'FPF_TIMEONSITE_DESC' => __('Target visitors who have spent a specific amount of time on your site.', 'fpf-framework'),
			'FPF_NO_ITEMS_FOUND' => __('No Items found.', 'fpf-framework'),
			'FPF_TYPE' => __('Type', 'fpf-framework'),
			'FPF_PA_POSTS_HINT' => __('Start searching for posts.', 'fpf-framework'),
			'FPF_PA_PAGES_HINT' => __('Start searching for pages.', 'fpf-framework'),
			'FPF_PA_POSTS_DESC' => __('Target specific posts', 'fpf-framework'),
			'FPF_PA_PAGES_DESC' => __('Target specific pages', 'fpf-framework'),
			'FPF_PA_USER_ROLES_HINT' => __('Start searching for user roles.', 'fpf-framework'),
			'FPF_PA_CPTS_DESC' => __('Target specific custom post types', 'fpf-framework'),
			'FPF_PA_CPTS_HINT' => __('Start searching for custom post types.', 'fpf-framework'),
			'FPF_PA_TAGS_DESC' => __('Target specific post tags', 'fpf-framework'),
			'FPF_PA_POST_TAGS_HINT' => __('Start searching for post tags.', 'fpf-framework'),
			'FPF_PA_POST_CATEGORIES_DESC' => __('Target specific post categories', 'fpf-framework'),
			'FPF_PA_POST_CATEGORIES_HINT' => __('Start searching for post categories.', 'fpf-framework'),
			'FPF_REFERRER_URL' => __('Referrer URL', 'fpf-framework'),
			'FPF_REFERRER_URL_DESC' => __('Target visitors who land on your site from a specific traffic source', 'fpf-framework'),
			'FPF_REFERRER_URL_SELECTION_DESC' => __('Enter one Referrer URL per line. Example:<br>google.com<br>facebook.com/mypage', 'fpf-framework'),
			'FPF_REFERRER_URL_DESC' => __('Keep in mind that URL Referrer discovery is not always 100% accurate. Some servers may use proxies that strip this information out and it can be easily forged.', 'fpf-framework'),
			'FPF_IP_ADDRESS' => __('IP Address', 'fpf-framework'),
			'FPF_IP_ADDRESS_DESC' => __('Target visitors who are behind a specific IP address (range)', 'fpf-framework'),
			'FPF_IP_ADDRESS_SELECTION_DESC' => __('Enter a list of comma and/or \'enter\' separated ip addresses and ranges. Example:<br /> 127.0.0.1,<br /> 192.10-120.2,<br /> 168', 'fpf-framework'),
			'FPF_PHP' => __('PHP', 'fpf-framework'),
			'FPF_PHP_DESC' => __('Target visitors evaluating custom PHP code.', 'fpf-framework'),
			'FPF_PHP_CODE' => __('PHP Code', 'fpf-framework'),
			'FPF_PHP_SELECTION_DESC' => __('Enter a piece of PHP code to evaluate.  The code must return the value true or false. Example: <Br>$current_user = wp_get_current_user();<br>return ($current_user->display_name == \'John_Doe\');<br><br>A collection of ready-to-use PHP assignment scripts is available. <a target="_blank" href="http://www.fireplugins.com/docs/general/extending-general/custom-php-assignments/">View collection</a>', 'fpf-framework'),
			'FPF_COOKIE' => __('Cookie', 'fpf-framework'),
			'FPF_PA_COOKIE_DESC' => __('Target visitors who have specific cookies stored in their browser', 'fpf-framework'),
			'FPF_COOKIE_NAME' => __('Cookie Name', 'fpf-framework'),
			'FPF_PA_COOKIE_NAME_DESC' => __('Enter the name of the cookie to assign to', 'fpf-framework'),
			'FPF_MATCH' => __('Match', 'fpf-framework'),
			'FPF_PA_MATCH_DESC' => __('The used matching method to compare the value', 'fpf-framework'),
			'FPF_EXISTS' => __('Exists', 'fpf-framework'),
			'FPF_EQUALS' => __('Equals', 'fpf-framework'),
			'FPF_CONTAINS' => __('Contains', 'fpf-framework'),
			'FPF_STARTS_WITH' => __('Starts With', 'fpf-framework'),
			'FPF_ENDS_WITH' => __('Ends With', 'fpf-framework'),
			'FPF_COOKIE_NAME_PARAM_CONTENT' => __('Cookie Content', 'fpf-framework'),
			'FPF_PA_COOKIE_NAME_PARAM_CONTENT_DESC' => __('The cookie\'s content', 'fpf-framework'),
			'FPF_METABOX_PA_VISITOR_PLATFORM' => __('Visitor Platform', 'fpf-framework'),
			'FPF_METABOX_PA_VISITOR_PLATFORM_DESC' => __('Target visitors who are using Mobile, Google Chrome, or even Windows', 'fpf-framework'),
			'FPF_PA_DEVICES_DESC2' => __('Keep in mind that device detection is not always 100% accurate. Users can setup their browser to mimic other devices.', 'fpf-framework'),
			'FPF_DEVICE' => __('Device', 'fpf-framework'),
			'FPF_DEVICES' => __('Devices', 'fpf-framework'),
			'FPF_PA_DEVICE_DESC' => __('Target visitors using specific device such as Mobile, Tablet or Desktop.', 'fpf-framework'),
			'FPF_PA_DEVICES_HINT' => __('Start searching for devices.', 'fpf-framework'),
			'FPF_DESKTOP' => __('Desktop', 'fpf-framework'),
			'FPF_TABLET' => __('Tablet', 'fpf-framework'),
			'FPF_MOBILE' => __('Mobile', 'fpf-framework'),
			'FPF_X_DEVICE_SETTINGS' => __('%s device settings', 'fpf-frameowrk'),
			'FPF_CHROME' => __('Chrome', 'fpf-framework'),
			'FPF_FIREFOX' => __('Firefox', 'fpf-framework'),
			'FPF_EDGE' => __('Edge', 'fpf-framework'),
			'FPF_IE' => __('Internet Explorer', 'fpf-framework'),
			'FPF_SAFARI' => __('Safari', 'fpf-framework'),
			'FPF_OPERA' => __('Opera', 'fpf-framework'),
			'FPF_BROWSER' => __('Browser', 'fpf-framework'),
			'FPF_PA_BROWSER_DESC' => __('Target visitors who are browsing your site with specific browsers such as Chrome, Firefox or Internet Explorer', 'fpf-framework'),
			'FPF_PA_BROWSERS_AS_DESC' => __('Select the browsers to assign to', 'fpf-framework'),
			'FPF_PA_BROWSERS_HINT' => __('Start searching for browsers.', 'fpf-framework'),
			'FPF_OS' => __('Operating System', 'fpf-framework'),
			'FPF_PA_OS_DESC' => __('Target visitors who are using specific operating systems such as Windows, Linux or Mac', 'fpf-framework'),
			'FPF_PA_OSES_AS_DESC' => __('Select the operating systems to assign to', 'fpf-framework'),
			'FPF_PA_OSES_HINT' => __('Start searching for operating systems.', 'fpf-framework'),
			'FPF_LINUX' => __('Linux', 'fpf-framework'),
			'FPF_MAC' => __('MacOS', 'fpf-framework'),
			'FPF_ANDROID' => __('Android', 'fpf-framework'),
			'FPF_IOS' => __('iOS', 'fpf-framework'),
			'FPF_WINDOWS' => __('Windows', 'fpf-framework'),
			'FPF_BLACKBERRY' => __('Blackberry', 'fpf-framework'),
			'FPF_CHROMEOS' => __('Chrome OS', 'fpf-framework'),
			'FPF_PA_GEOLOCATING' => __('Geolocating', 'fpf-framework'),
			'FPF_PA_GEOLOCATING_DESC' => __('Target visitors who are physically in a specific region', 'fpf-framework'),
			'FPF_CONTINENT' => __('Continent', 'fpf-framework'),
			'FPF_CONTINENT_DESC' => __('Target visitors who are physically in a specific continent', 'fpf-framework'),
			'FPF_PA_CONTINENT_HINT' => __('Start searching for continents.', 'fpf-framework'),
			'FPF_PA_CONTINENT_AS_DESC' => __('Select the continents to assign to.', 'fpf-framework'),
			'FPF_CONTINENT_AF' => __('Africa', 'fpf-framework'),
			'FPF_CONTINENT_AS' => __('Asia', 'fpf-framework'),
			'FPF_CONTINENT_EU' => __('Europe', 'fpf-framework'),
			'FPF_CONTINENT_NA' => __('North America', 'fpf-framework'),
			'FPF_CONTINENT_SA' => __('South America', 'fpf-framework'),
			'FPF_CONTINENT_OC' => __('Oceania', 'fpf-framework'),
			'FPF_CONTINENT_AN' => __('Antartica', 'fpf-framework'),
			'FPF_COUNTRY' => __('Country', 'fpf-framework'),
			'FPF_COUNTRIES' => __('Countries', 'fpf-framework'),
			'FPF_COUNTRY_CODE' => __('Country Code', 'fpf-framework'),
			'FPF_CITY' => __('City', 'fpf-framework'),
			'FPF_COUNTRY_DESC' => __('Target visitors who are physically in a specific country', 'fpf-framework'),
			'FPF_PA_COUNTRY_AS_DESC' => __('Select the countries to assign to', 'fpf-framework'),
			'FPF_PA_COUNTRY_HINT' => __('Start searching for countries.', 'fpf-framework'),
			'FPF_COUNTRY_AF' => __('Afghanistan', 'fpf-framework'),
			'FPF_COUNTRY_AX' => __('Aland Islands', 'fpf-framework'),
			'FPF_COUNTRY_AL' => __('Albania', 'fpf-framework'),
			'FPF_COUNTRY_DZ' => __('Algeria', 'fpf-framework'),
			'FPF_COUNTRY_AS' => __('American Samoa', 'fpf-framework'),
			'FPF_COUNTRY_AD' => __('Andorra', 'fpf-framework'),
			'FPF_COUNTRY_AO' => __('Angola', 'fpf-framework'),
			'FPF_COUNTRY_AI' => __('Anguilla', 'fpf-framework'),
			'FPF_COUNTRY_AQ' => __('Antarctica', 'fpf-framework'),
			'FPF_COUNTRY_AG' => __('Antigua and Barbuda', 'fpf-framework'),
			'FPF_COUNTRY_AR' => __('Argentina', 'fpf-framework'),
			'FPF_COUNTRY_AM' => __('Armenia', 'fpf-framework'),
			'FPF_COUNTRY_AW' => __('Aruba', 'fpf-framework'),
			'FPF_COUNTRY_AU' => __('Australia', 'fpf-framework'),
			'FPF_COUNTRY_AT' => __('Austria', 'fpf-framework'),
			'FPF_COUNTRY_AZ' => __('Azerbaijan', 'fpf-framework'),
			'FPF_COUNTRY_BS' => __('Bahamas', 'fpf-framework'),
			'FPF_COUNTRY_BH' => __('Bahrain', 'fpf-framework'),
			'FPF_COUNTRY_BD' => __('Bangladesh', 'fpf-framework'),
			'FPF_COUNTRY_BB' => __('Barbados', 'fpf-framework'),
			'FPF_COUNTRY_BY' => __('Belarus', 'fpf-framework'),
			'FPF_COUNTRY_BE' => __('Belgium', 'fpf-framework'),
			'FPF_COUNTRY_BZ' => __('Belize', 'fpf-framework'),
			'FPF_COUNTRY_BJ' => __('Benin', 'fpf-framework'),
			'FPF_COUNTRY_BM' => __('Bermuda', 'fpf-framework'),
			'FPF_COUNTRY_BQ-BO' => __('Bonaire', 'fpf-framework'),
			'FPF_COUNTRY_BQ-SA' => __('Saba', 'fpf-framework'),
			'FPF_COUNTRY_BQ-SE' => __('Sint Eustatius', 'fpf-framework'),
			'FPF_COUNTRY_BT' => __('Bhutan', 'fpf-framework'),
			'FPF_COUNTRY_BO' => __('Bolivia', 'fpf-framework'),
			'FPF_COUNTRY_BA' => __('Bosnia and Herzegovina', 'fpf-framework'),
			'FPF_COUNTRY_BW' => __('Botswana', 'fpf-framework'),
			'FPF_COUNTRY_BV' => __('Bouvet Island', 'fpf-framework'),
			'FPF_COUNTRY_BR' => __('Brazil', 'fpf-framework'),
			'FPF_COUNTRY_IO' => __('British Indian Ocean Territory', 'fpf-framework'),
			'FPF_COUNTRY_BN' => __('Brunei Darussalam', 'fpf-framework'),
			'FPF_COUNTRY_BG' => __('Bulgaria', 'fpf-framework'),
			'FPF_COUNTRY_BF' => __('Burkina Faso', 'fpf-framework'),
			'FPF_COUNTRY_BI' => __('Burundi', 'fpf-framework'),
			'FPF_COUNTRY_KH' => __('Cambodia', 'fpf-framework'),
			'FPF_COUNTRY_CM' => __('Cameroon', 'fpf-framework'),
			'FPF_COUNTRY_CA' => __('Canada', 'fpf-framework'),
			'FPF_COUNTRY_CV' => __('Cape Verde', 'fpf-framework'),
			'FPF_COUNTRY_KY' => __('Cayman Islands', 'fpf-framework'),
			'FPF_COUNTRY_CF' => __('Central African Republic', 'fpf-framework'),
			'FPF_COUNTRY_TD' => __('Chad', 'fpf-framework'),
			'FPF_COUNTRY_CL' => __('Chile', 'fpf-framework'),
			'FPF_COUNTRY_CN' => __('China', 'fpf-framework'),
			'FPF_COUNTRY_CX' => __('Christmas Island', 'fpf-framework'),
			'FPF_COUNTRY_CC' => __('Cocos (Keeling) Islands', 'fpf-framework'),
			'FPF_COUNTRY_CO' => __('Colombia', 'fpf-framework'),
			'FPF_COUNTRY_KM' => __('Comoros', 'fpf-framework'),
			'FPF_COUNTRY_CG' => __('Congo', 'fpf-framework'),
			'FPF_COUNTRY_CD' => __('Congo, The Democratic Republic of the', 'fpf-framework'),
			'FPF_COUNTRY_CK' => __('Cook Islands', 'fpf-framework'),
			'FPF_COUNTRY_CR' => __('Costa Rica', 'fpf-framework'),
			'FPF_COUNTRY_CI' => __('Cote d\'Ivoire', 'fpf-framework'),
			'FPF_COUNTRY_HR' => __('Croatia', 'fpf-framework'),
			'FPF_COUNTRY_CU' => __('Cuba', 'fpf-framework'),
			'FPF_COUNTRY_CW' => __('Curaçao', 'fpf-framework'),
			'FPF_COUNTRY_CY' => __('Cyprus', 'fpf-framework'),
			'FPF_COUNTRY_CZ' => __('Czech Republic', 'fpf-framework'),
			'FPF_COUNTRY_DK' => __('Denmark', 'fpf-framework'),
			'FPF_COUNTRY_DJ' => __('Djibouti', 'fpf-framework'),
			'FPF_COUNTRY_DM' => __('Dominica', 'fpf-framework'),
			'FPF_COUNTRY_DO' => __('Dominican Republic', 'fpf-framework'),
			'FPF_COUNTRY_EC' => __('Ecuador', 'fpf-framework'),
			'FPF_COUNTRY_EG' => __('Egypt', 'fpf-framework'),
			'FPF_COUNTRY_SV' => __('El Salvador', 'fpf-framework'),
			'FPF_COUNTRY_GQ' => __('Equatorial Guinea', 'fpf-framework'),
			'FPF_COUNTRY_ER' => __('Eritrea', 'fpf-framework'),
			'FPF_COUNTRY_EE' => __('Estonia', 'fpf-framework'),
			'FPF_COUNTRY_ET' => __('Ethiopia', 'fpf-framework'),
			'FPF_COUNTRY_FK' => __('Falkland Islands (Malvinas)', 'fpf-framework'),
			'FPF_COUNTRY_FO' => __('Faroe Islands', 'fpf-framework'),
			'FPF_COUNTRY_FJ' => __('Fiji', 'fpf-framework'),
			'FPF_COUNTRY_FI' => __('Finland', 'fpf-framework'),
			'FPF_COUNTRY_FR' => __('France', 'fpf-framework'),
			'FPF_COUNTRY_GF' => __('French Guiana', 'fpf-framework'),
			'FPF_COUNTRY_PF' => __('French Polynesia', 'fpf-framework'),
			'FPF_COUNTRY_TF' => __('French Southern Territories', 'fpf-framework'),
			'FPF_COUNTRY_GA' => __('Gabon', 'fpf-framework'),
			'FPF_COUNTRY_GM' => __('Gambia', 'fpf-framework'),
			'FPF_COUNTRY_GE' => __('Georgia', 'fpf-framework'),
			'FPF_COUNTRY_DE' => __('Germany', 'fpf-framework'),
			'FPF_COUNTRY_GH' => __('Ghana', 'fpf-framework'),
			'FPF_COUNTRY_GI' => __('Gibraltar', 'fpf-framework'),
			'FPF_COUNTRY_GR' => __('Greece', 'fpf-framework'),
			'FPF_COUNTRY_GL' => __('Greenland', 'fpf-framework'),
			'FPF_COUNTRY_GD' => __('Grenada', 'fpf-framework'),
			'FPF_COUNTRY_GP' => __('Guadeloupe', 'fpf-framework'),
			'FPF_COUNTRY_GU' => __('Guam', 'fpf-framework'),
			'FPF_COUNTRY_GT' => __('Guatemala', 'fpf-framework'),
			'FPF_COUNTRY_GG' => __('Guernsey', 'fpf-framework'),
			'FPF_COUNTRY_GN' => __('Guinea', 'fpf-framework'),
			'FPF_COUNTRY_GW' => __('Guinea-Bissau', 'fpf-framework'),
			'FPF_COUNTRY_GY' => __('Guyana', 'fpf-framework'),
			'FPF_COUNTRY_HT' => __('Haiti', 'fpf-framework'),
			'FPF_COUNTRY_HM' => __('Heard Island and McDonald Islands', 'fpf-framework'),
			'FPF_COUNTRY_VA' => __('Holy See (Vatican City State)', 'fpf-framework'),
			'FPF_COUNTRY_HN' => __('Honduras', 'fpf-framework'),
			'FPF_COUNTRY_HK' => __('Hong Kong', 'fpf-framework'),
			'FPF_COUNTRY_HU' => __('Hungary', 'fpf-framework'),
			'FPF_COUNTRY_IS' => __('Iceland', 'fpf-framework'),
			'FPF_COUNTRY_IN' => __('India', 'fpf-framework'),
			'FPF_COUNTRY_ID' => __('Indonesia', 'fpf-framework'),
			'FPF_COUNTRY_IR' => __('Iran, Islamic Republic of', 'fpf-framework'),
			'FPF_COUNTRY_IQ' => __('Iraq', 'fpf-framework'),
			'FPF_COUNTRY_IE' => __('Ireland', 'fpf-framework'),
			'FPF_COUNTRY_IM' => __('Isle of Man', 'fpf-framework'),
			'FPF_COUNTRY_IL' => __('Israel', 'fpf-framework'),
			'FPF_COUNTRY_IT' => __('Italy', 'fpf-framework'),
			'FPF_COUNTRY_JM' => __('Jamaica', 'fpf-framework'),
			'FPF_COUNTRY_JP' => __('Japan', 'fpf-framework'),
			'FPF_COUNTRY_JE' => __('Jersey', 'fpf-framework'),
			'FPF_COUNTRY_JO' => __('Jordan', 'fpf-framework'),
			'FPF_COUNTRY_KZ' => __('Kazakhstan', 'fpf-framework'),
			'FPF_COUNTRY_KE' => __('Kenya', 'fpf-framework'),
			'FPF_COUNTRY_KI' => __('Kiribati', 'fpf-framework'),
			'FPF_COUNTRY_KP' => __('Korea, Democratic People\'s Republic of', 'fpf-framework'),
			'FPF_COUNTRY_KR' => __('Korea, Republic of', 'fpf-framework'),
			'FPF_COUNTRY_KW' => __('Kuwait', 'fpf-framework'),
			'FPF_COUNTRY_KG' => __('Kyrgyzstan', 'fpf-framework'),
			'FPF_COUNTRY_LA' => __('Lao People\'s Democratic Republic', 'fpf-framework'),
			'FPF_COUNTRY_LV' => __('Latvia', 'fpf-framework'),
			'FPF_COUNTRY_LB' => __('Lebanon', 'fpf-framework'),
			'FPF_COUNTRY_LS' => __('Lesotho', 'fpf-framework'),
			'FPF_COUNTRY_LR' => __('Liberia', 'fpf-framework'),
			'FPF_COUNTRY_LY' => __('Libyan Arab Jamahiriya', 'fpf-framework'),
			'FPF_COUNTRY_LI' => __('Liechtenstein', 'fpf-framework'),
			'FPF_COUNTRY_LT' => __('Lithuania', 'fpf-framework'),
			'FPF_COUNTRY_LU' => __('Luxembourg', 'fpf-framework'),
			'FPF_COUNTRY_MO' => __('Macao', 'fpf-framework'),
			'FPF_COUNTRY_MK' => __('Macedonia', 'fpf-framework'),
			'FPF_COUNTRY_MG' => __('Madagascar', 'fpf-framework'),
			'FPF_COUNTRY_MW' => __('Malawi', 'fpf-framework'),
			'FPF_COUNTRY_MY' => __('Malaysia', 'fpf-framework'),
			'FPF_COUNTRY_MV' => __('Maldives', 'fpf-framework'),
			'FPF_COUNTRY_ML' => __('Mali', 'fpf-framework'),
			'FPF_COUNTRY_MT' => __('Malta', 'fpf-framework'),
			'FPF_COUNTRY_MH' => __('Marshall Islands', 'fpf-framework'),
			'FPF_COUNTRY_MQ' => __('Martinique', 'fpf-framework'),
			'FPF_COUNTRY_MR' => __('Mauritania', 'fpf-framework'),
			'FPF_COUNTRY_MU' => __('Mauritius', 'fpf-framework'),
			'FPF_COUNTRY_YT' => __('Mayotte', 'fpf-framework'),
			'FPF_COUNTRY_MX' => __('Mexico', 'fpf-framework'),
			'FPF_COUNTRY_FM' => __('Federated States of Micronesia', 'fpf-framework'),
			'FPF_COUNTRY_MD' => __('Moldova, Republic of', 'fpf-framework'),
			'FPF_COUNTRY_MC' => __('Monaco', 'fpf-framework'),
			'FPF_COUNTRY_MN' => __('Mongolia', 'fpf-framework'),
			'FPF_COUNTRY_ME' => __('Montenegro', 'fpf-framework'),
			'FPF_COUNTRY_MS' => __('Montserrat', 'fpf-framework'),
			'FPF_COUNTRY_MA' => __('Morocco', 'fpf-framework'),
			'FPF_COUNTRY_MZ' => __('Mozambique', 'fpf-framework'),
			'FPF_COUNTRY_MM' => __('Myanmar', 'fpf-framework'),
			'FPF_COUNTRY_NA' => __('Namibia', 'fpf-framework'),
			'FPF_COUNTRY_NR' => __('Nauru', 'fpf-framework'),
			'FPF_COUNTRY_NP' => __('Nepal', 'fpf-framework'),
			'FPF_COUNTRY_NL' => __('Netherlands', 'fpf-framework'),
			'FPF_COUNTRY_AN' => __('Netherlands Antilles', 'fpf-framework'),
			'FPF_COUNTRY_NC' => __('New Caledonia', 'fpf-framework'),
			'FPF_COUNTRY_NZ' => __('New Zealand', 'fpf-framework'),
			'FPF_COUNTRY_NI' => __('Nicaragua', 'fpf-framework'),
			'FPF_COUNTRY_NE' => __('Niger', 'fpf-framework'),
			'FPF_COUNTRY_NG' => __('Nigeria', 'fpf-framework'),
			'FPF_COUNTRY_NU' => __('Niue', 'fpf-framework'),
			'FPF_COUNTRY_NF' => __('Norfolk Island', 'fpf-framework'),
			'FPF_COUNTRY_MP' => __('Northern Mariana Islands', 'fpf-framework'),
			'FPF_COUNTRY_NO' => __('Norway', 'fpf-framework'),
			'FPF_COUNTRY_OM' => __('Oman', 'fpf-framework'),
			'FPF_COUNTRY_PK' => __('Pakistan', 'fpf-framework'),
			'FPF_COUNTRY_PW' => __('Palau', 'fpf-framework'),
			'FPF_COUNTRY_PS' => __('Palestinian Territory', 'fpf-framework'),
			'FPF_COUNTRY_PA' => __('Panama', 'fpf-framework'),
			'FPF_COUNTRY_PG' => __('Papua New Guinea', 'fpf-framework'),
			'FPF_COUNTRY_PY' => __('Paraguay', 'fpf-framework'),
			'FPF_COUNTRY_PE' => __('Peru', 'fpf-framework'),
			'FPF_COUNTRY_PH' => __('Philippines', 'fpf-framework'),
			'FPF_COUNTRY_PN' => __('Pitcairn', 'fpf-framework'),
			'FPF_COUNTRY_PL' => __('Poland', 'fpf-framework'),
			'FPF_COUNTRY_PT' => __('Portugal', 'fpf-framework'),
			'FPF_COUNTRY_PR' => __('Puerto Rico', 'fpf-framework'),
			'FPF_COUNTRY_QA' => __('Qatar', 'fpf-framework'),
			'FPF_COUNTRY_RE' => __('Reunion', 'fpf-framework'),
			'FPF_COUNTRY_RO' => __('Romania', 'fpf-framework'),
			'FPF_COUNTRY_RU' => __('Russian Federation', 'fpf-framework'),
			'FPF_COUNTRY_RW' => __('Rwanda', 'fpf-framework'),
			'FPF_COUNTRY_SH' => __('Saint Helena', 'fpf-framework'),
			'FPF_COUNTRY_KN' => __('Saint Kitts and Nevis', 'fpf-framework'),
			'FPF_COUNTRY_LC' => __('Saint Lucia', 'fpf-framework'),
			'FPF_COUNTRY_PM' => __('Saint Pierre and Miquelon', 'fpf-framework'),
			'FPF_COUNTRY_VC' => __('Saint Vincent and the Grenadines', 'fpf-framework'),
			'FPF_COUNTRY_WS' => __('Samoa', 'fpf-framework'),
			'FPF_COUNTRY_SM' => __('San Marino', 'fpf-framework'),
			'FPF_COUNTRY_ST' => __('Sao Tome and Principe', 'fpf-framework'),
			'FPF_COUNTRY_SA' => __('Saudi Arabia', 'fpf-framework'),
			'FPF_COUNTRY_SN' => __('Senegal', 'fpf-framework'),
			'FPF_COUNTRY_RS' => __('Serbia', 'fpf-framework'),
			'FPF_COUNTRY_SC' => __('Seychelles', 'fpf-framework'),
			'FPF_COUNTRY_SL' => __('Sierra Leone', 'fpf-framework'),
			'FPF_COUNTRY_SG' => __('Singapore', 'fpf-framework'),
			'FPF_COUNTRY_SK' => __('Slovakia', 'fpf-framework'),
			'FPF_COUNTRY_SI' => __('Slovenia', 'fpf-framework'),
			'FPF_COUNTRY_SB' => __('Solomon Islands', 'fpf-framework'),
			'FPF_COUNTRY_SO' => __('Somalia', 'fpf-framework'),
			'FPF_COUNTRY_ZA' => __('South Africa', 'fpf-framework'),
			'FPF_COUNTRY_GS' => __('South Georgia and the South Sandwich Islands', 'fpf-framework'),
			'FPF_COUNTRY_ES' => __('Spain', 'fpf-framework'),
			'FPF_COUNTRY_LK' => __('Sri Lanka', 'fpf-framework'),
			'FPF_COUNTRY_SD' => __('Sudan', 'fpf-framework'),
			'FPF_COUNTRY_SS' => __('South Sudan', 'fpf-framework'),
			'FPF_COUNTRY_SR' => __('Suriname', 'fpf-framework'),
			'FPF_COUNTRY_SJ' => __('Svalbard and Jan Mayen', 'fpf-framework'),
			'FPF_COUNTRY_SZ' => __('Swaziland', 'fpf-framework'),
			'FPF_COUNTRY_SE' => __('Sweden', 'fpf-framework'),
			'FPF_COUNTRY_CH' => __('Switzerland', 'fpf-framework'),
			'FPF_COUNTRY_SY' => __('Syrian Arab Republic', 'fpf-framework'),
			'FPF_COUNTRY_TW' => __('Taiwan', 'fpf-framework'),
			'FPF_COUNTRY_TJ' => __('Tajikistan', 'fpf-framework'),
			'FPF_COUNTRY_TZ' => __('Tanzania, United Republic of', 'fpf-framework'),
			'FPF_COUNTRY_TH' => __('Thailand', 'fpf-framework'),
			'FPF_COUNTRY_TL' => __('Timor-Leste', 'fpf-framework'),
			'FPF_COUNTRY_TG' => __('Togo', 'fpf-framework'),
			'FPF_COUNTRY_TK' => __('Tokelau', 'fpf-framework'),
			'FPF_COUNTRY_TO' => __('Tonga', 'fpf-framework'),
			'FPF_COUNTRY_TT' => __('Trinidad and Tobago', 'fpf-framework'),
			'FPF_COUNTRY_TN' => __('Tunisia', 'fpf-framework'),
			'FPF_COUNTRY_TR' => __('Turkey', 'fpf-framework'),
			'FPF_COUNTRY_TM' => __('Turkmenistan', 'fpf-framework'),
			'FPF_COUNTRY_TC' => __('Turks and Caicos Islands', 'fpf-framework'),
			'FPF_COUNTRY_TV' => __('Tuvalu', 'fpf-framework'),
			'FPF_COUNTRY_UG' => __('Uganda', 'fpf-framework'),
			'FPF_COUNTRY_UA' => __('Ukraine', 'fpf-framework'),
			'FPF_COUNTRY_AE' => __('United Arab Emirates', 'fpf-framework'),
			'FPF_COUNTRY_GB' => __('United Kingdom', 'fpf-framework'),
			'FPF_COUNTRY_US' => __('United States', 'fpf-framework'),
			'FPF_COUNTRY_UM' => __('United States Minor Outlying Islands', 'fpf-framework'),
			'FPF_COUNTRY_UY' => __('Uruguay', 'fpf-framework'),
			'FPF_COUNTRY_UZ' => __('Uzbekistan', 'fpf-framework'),
			'FPF_COUNTRY_VU' => __('Vanuatu', 'fpf-framework'),
			'FPF_COUNTRY_VE' => __('Venezuela', 'fpf-framework'),
			'FPF_COUNTRY_VN' => __('Vietnam', 'fpf-framework'),
			'FPF_COUNTRY_VG' => __('Virgin Islands, British', 'fpf-framework'),
			'FPF_COUNTRY_VI' => __('Virgin Islands, U.S.', 'fpf-framework'),
			'FPF_COUNTRY_WF' => __('Wallis and Futuna', 'fpf-framework'),
			'FPF_COUNTRY_EH' => __('Western Sahara', 'fpf-framework'),
			'FPF_COUNTRY_YE' => __('Yemen', 'fpf-framework'),
			'FPF_COUNTRY_ZM' => __('Zambia', 'fpf-framework'),
			'FPF_COUNTRY_ZW' => __('Zimbabwe', 'fpf-framework'),
			'FPF_SMART_TAGS_TITLE' => __('Smart Tags', 'fpf-framework'),
			'FPF_TAG_CLIENTDEVICE' => __('Visitor Device Type', 'fpf-framework'),
			'FPF_TAG_CLIENTOS' => __('Visitor Operating System', 'fpf-framework'),
			'FPF_TAG_CLIENTBROWSER' => __('Visitor Browser', 'fpf-framework'),
			'FPF_TAG_CLIENTUSERAGENT' => __('Visitor Agent String', 'fpf-framework'),
			'FPF_TAG_IP' => __('Visitor IP Address', 'fpf-framework'),
			'FPF_TAG_URL' => __('Page URL', 'fpf-framework'),
			'FPF_TAG_URLENCODED' => __('Page URL Encoded', 'fpf-framework'),
			'FPF_TAG_URLPATH' => __('Page Path', 'fpf-framework'),
			'FPF_TAG_REFERRER' => __('Page Referrer', 'fpf-framework'),
			'FPF_TAG_SITENAME' => __('Site Name', 'fpf-framework'),
			'FPF_TAG_SITEEMAIL' => __('Site Email', 'fpf-framework'),
			'FPF_TAG_SITEURL' => __('Site URL', 'fpf-framework'),
			'FPF_TAG_PAGETITLE' => __('Page Title', 'fpf-framework'),
			'FPF_TAG_PAGEDESC' => __('Page Meta Description', 'fpf-framework'),
			'FPF_TAG_PAGELANG' => __('Page Language Code', 'fpf-framework'),
			'FPF_TAG_PAGELANGURL' => __('Page Language Code URL', 'fpf-framework'),
			'FPF_TAG_PAGEBROWSERTITLE' => __('Browser Title', 'fpf-framework'),
			'FPF_TAG_USERID' => __('User ID', 'fpf-framework'),
			'FPF_TAG_USERNAME' => __('User Full Name', 'fpf-framework'),
			'FPF_TAG_USERLOGIN' => __('User Login', 'fpf-framework'),
			'FPF_TAG_USEREMAIL' => __('User Email', 'fpf-framework'),
			'FPF_TAG_USERFIRSTNAME' => __('User First Name', 'fpf-framework'),
			'FPF_TAG_USERLASTNAME' => __('User Last Name', 'fpf-framework'),
			'FPF_TAG_USERROLES' => __('User Roles', 'fpf-framework'),
			'FPF_TAG_USERREGISTERDATE' => __('User Register Date', 'fpf-framework'),
			'FPF_TAG_DATE' => __('Date', 'fpf-framework'),
			'FPF_TAG_TIME' => __('Time', 'fpf-framework'),
			'FPF_TAG_RANDOMID' => __('Random ID', 'fpf-framework'),
			'FPF_TAG_DAY' => __('Day', 'fpf-framework'),
			'FPF_TAG_MONTH' => __('Month', 'fpf-framework'),
			'FPF_TAG_YEAR' => __('Year', 'fpf-framework'),
			'FPF_CLOSE' => __('Close', 'fpf-framework'),
			'FPF_SYNTAX' => __('Syntax', 'fpf-framework'),
			'FPF_DESC' => __('Description', 'fpf-framework'),
			'FPF_OUTPUT_EXAMPLE' => __('Output example', 'fpf-framework'),
			'FPF_LANGUAGE' => __('Language', 'fpf-framework'),
			'FPF_WPML_LANGUAGE' => __('WPML Language', 'fpf-framework'),
			'FPF_LANGUAGE_DESC' => __('Target visitors who are browsing your website in a specific language', 'fpf-framework'),
			'FPF_PA_LANGUAGE_HINT' => __('Start searching for languages', 'fpf-framework'),
			'FPF_PA_LANGUAGE_AS_DESC' => __('Select the Languages to assign to', 'fpf-framework'),
			'FPF_TAG_FBID' => __('Popup ID', 'fpf-framework'),
			'FPF_TAG_FBTITLE' => __('Popup Title', 'fpf-framework'),
			'FPF_EXPORT' => __('Export', 'fpf-framework'),
			'FPF_GENERAL' => __('General', 'fpf-framework'),
			'FPF_AS_EXPORTED' => __('As Exported', 'fpf-framework'),
			'FPF_SELECT_IMPORT_FILE' => __('Select Import File', 'fpf-framework'),
			'FPF_IMPORT_ITEMS' => __('Import Items', 'fpf-framework'),
			'FPF_DUPLICATE' => __('Duplicate', 'fpf-framework'),
			'FPF_PERCENTAGE' => __('Percentage', 'fpf-framework'),
			'FPF_PIXEL' => __('Pixel', 'fpf-framework'),
			'FPF_DOWN' => __('Down', 'fpf-framework'),
			'FPF_UP' => __('Up', 'fpf-framework'),
			'FPF_DESIGN' => __('Design', 'fpf-framework'),
			'FPF_ADD_ITEM' => __('Add Item', 'fpf-framework'),
			'FPF_EVENT' => __('Event', 'fpf-framework'),
			'FPF_EVENTS' => __('Events', 'fpf-framework'),
			'FPF_SELECT_AN_EVENT' => __('Select an event', 'fpf-framework'),
			'FPF_BEFORE_OPEN' => __('Before Open', 'fpf-framework'),
			'FPF_OPEN' => __('Open', 'fpf-framework'),
			'FPF_TOGGLE' => __('Toggle', 'fpf-framework'),
			'FPF_AFTER_OPEN' => __('After Open', 'fpf-framework'),
			'FPF_BEFORE_CLOSE' => __('Before Close', 'fpf-framework'),
			'FPF_AFTER_CLOSE' => __('After Close', 'fpf-framework'),
			'FPF_ACTION' => __('Action', 'fpf-framework'),
			'FPF_ACTION_NAME' => __('Action Name', 'fpf-framework'),
			'FPF_PLEASE_SELECT_A_FILE_TO_UPLOAD' => __('Please select a file to upload.', 'fpf-framework'),
			'FPF_PLEASE_CHOOSE_A_VALID_FILE' => __('Please choose a valid file.', 'fpf-framework'),
			'FPF_FILE_EMPTY' => __('File is empty!', 'fpf-framework'),
			'FPF_ITEMS_SAVED' => __('Items saved!', 'fpf-framework'),
			'FPF_SETTINGS_SAVED' => __('Settings saved!', 'fpf-framework'),
			'FPF_MY_FAVORITES' => __('My Favorites', 'fpf-framework'),
			'FPF_OTHER' => __('Other', 'fpf-framework'),
			'FPF_PASSWORD' => __('Password', 'fpf-framework'),
			'FPF_REMEMBER_ME' => __('Remember Me', 'fpf-framework'),
			'FPF_LOG_IN' => __('Log in', 'fpf-framework'),
			'FPF_LOG_OUT' => __('Log out', 'fpf-framework'),
			'FPF_GUEST' => __('Guest', 'fpf-framework'),
			'FPF_PLEASE_SELECT' => __('Please Select', 'fpf-framework'),
			'FPF_GEOLOCATION_SERVICES' => __('Geolocation Services', 'fpf-framework'),
			'FPF_LICENSE' => __('License', 'fpf-framework'),
			'FPF_GEOIP_LICENSE_KEY_DESC' => __('Get your free License Key to download the latest MaxMind GeoLite2 Database.', 'fpf-framework'),
			'FPF_GEOLOCATION' => __('Geolocation', 'fpf-framework'),
			'FPF_GEOIP_GEOLOCATION_SERVICES' => __('Geolocation Services', 'fpf-framework'),
			'FPF_GEOIP_LICENSE_KEY_GET' => __('Get a free License Key', 'fpf-framework'),
			'FPF_GEOIP_GEOLOCATION_SERVICES_HEADING_DESC' => __('Geolocation services provide features such as (finding out the country of an IP address as well as retrieving the country data for Analytics) for Fireplugins.com plugins. Without it the geolocation features will not be available. This includes GeoLite2 data created by MaxMind <a href="http://www.maxmind.com">http://www.maxmind.com</a>.', 'fpf-framework'),
			'FPF_GEOIP_UPDATE_DB' => __('Update Database', 'fpf-framework'),
			'FPF_GEOIP_UPDATE_DB_DESC' => __('Update the GeoLite2 database from MaxMind servers. This might take several seconds to finish. Please be patient.', 'fpf-framework'),
			'FPF_GEOIP_DATABASE_UPDATED' => __('GeoIP database successfully updated!', 'fpf-framework'),
			'FPF_GEOIP_LICENSE_KEY_EMPTY' => __('Please enter a valid License Key.', 'fpf-framework'),
			'FPF_GEOIP_ERR_MAXMIND_GENERIC' => __('A connection error occurred. Please retry updating the GeoLite2 Country database in 24 hours.', 'fpf-framework'),
			'FPF_GEOIP_ERR_EMPTYDOWNLOAD' => __('Downloading the GeoLite2 Country database failed: empty file retrieved from server. Please contact your host.', 'fpf-framework'),
			'FPF_GEOIP_ERR_UNAUTHORIZED' => __('You have supplied an invalid MaxMind license key.', 'fpf-framework'),
			'FPF_GEOIP_ERR_CANTWRITE' => __('Insufficient rights while trying to save GeoIP database.', 'fpf-framework'),
			'FPF_GEOIP_ERR_INVALIDDB' => __('Downloaded database seems to be invalid. Please retry updating the GeoLite2 Country database in 24 hours.', 'fpf-framework'),
			'FPF_LAST_UPDATED' => __('Last Updated', 'fpf-framework'),
			'FPF_GEOIP_LAST_UPDATED_DESC' => __('Indicates the last datetime the database updated.', 'fpf-framework'),
			'FPF_GEOIP_LOOKUP' => __('Lookup IP Address', 'fpf-framework'),
			'FPF_GEOIP_LOOKUP_DESC' => __('Test drive the GeoIP plugin by looking up an IP address.', 'fpf-framework'),
			'FPF_LOOKUP' => __('Lookup', 'fpf-framework'),
			'FPF_LICENSE_KEY' => __('License Key', 'fpf-framework'),
			'FPF_LICENSE_KEY_DESC' => __('To find your License Key log-in to <a href="https://fireplugins.com" target="_blank">FirePlugins</a> and then go to your downloads section.', 'fpf-framework'),
			'FPF_FIND_LICENSE_KEY' => __('Find License Key', 'fpf-framework'),
			'FPF_DATA' => __('Data', 'fpf-framework'),
			'FPF_UPGRADE_TO_PRO_TO_UNLOCK_TEMPLATE' => __('Upgrade to Pro to unlock this template', 'fpf-framework'),
			'FPF_GEOIP_MAINTENANCE' => __('GeoIP Database Maintenance', 'fpf-framework'),
			'FPF_GEOIP_MAINTENANCE_DESC' => __('%s finds the country of your visitors\' IP addresses using the MaxMind GeoLite2 Country database. You are advised to update it at least once per month. On most servers you can perform the update by clicking the button below.', 'fpf-framework'),
			'FPF_GEOIP_MAINTENANCE_WITHOUT_BTN_MENTION_DESC' => __('%s finds the country of your visitors\' IP addresses using the MaxMind GeoLite2 Country database. You are advised to update it at least once per month.', 'fpf-framework'),
			'FPF_UPGRADE_TO_PRO' => __('Upgrade to Pro', 'fpf-framework'),
			'FPF_UPGRADE' => __('Upgrade', 'fpf-framework'),
			'FPF_VIEW_PLANS' => __('View Plans', 'fpf-framework'),
			'FPF_UNLOCK' => __('Unlock', 'fpf-framework'),
			'FPF_FREE' => __('Free', 'fpf-framework'),
			'FPF_PRO' => __('Pro', 'fpf-framework'),
			'FPF_PRO_MODAL_IS_PRO_FEATURE' => __('<em class="pro-feature-name"></em> is a PRO Feature', 'fpf-framework'),
			'FPF_PRO_MODAL_WERE_SORRY' => __('We\'re sorry, <em class="pro-feature-name"></em> is not available on your plan. Please upgrade to the PRO plan to unlock all these awesome features.', 'fpf-framework'),
			'FPF_PRO_MODAL_UPGRADE_TO_PRO_VERSION' => __('Awesome! Only one step left. Click on the button below to complete the upgrade to the Pro version.', 'fpf-framework'),
			'FPF_PRO_MODAL_PERCENTAGE_OFF' => __('<strong>Bonus</strong>: %s lite users get <strong>20%%</strong> off regular price, automatically applied at checkout.', 'fpf-framework'),
			'FPF_PRO_MODAL_PRESALES_QUESTIONS' => __('Pre-Sales questions? <a target="_blank" href="%s">Ask here</a>', 'fpf-framework'),
			'FPF_PRO_MODAL_UNLOCK_PRO_FEATURES' => __('Already purchased Pro? Learn how to <a target="_blank" href="%s">Unlock Pro Features</a>', 'fpf-framework'),
			'FPF_CLEAR' => __('Clear', 'fpf-framework'),
			'FPF_SAVE' => __('Save', 'fpf-framework'),
			'FPF_TOP' => __('Top', 'fpf-framework'),
			'FPF_RIGHT' => __('Right', 'fpf-framework'),
			'FPF_BOTTOM' => __('Bottom', 'fpf-framework'),
			'FPF_LEFT' => __('Left', 'fpf-framework'),
			'FPF_TOP_LEFT' => __('Top Left', 'fpf-framework'),
			'FPF_TOP_RIGHT' => __('Top Right', 'fpf-framework'),
			'FPF_BOTTOM_RIGHT' => __('Bottom Right', 'fpf-framework'),
			'FPF_BOTTOM_LEFT' => __('Bottom Left', 'fpf-framework'),
			'FPF_TAG_QUERYSTRINGPOST' => __('Post', 'fpf-framework'),
			'FPF_TAG_QUERYSTRINGACTION' => __('Action', 'fpf-framework'),
			'FPF_TAG_QUERYSTRINGLANG' => __('Lang', 'fpf-framework'),
			'FPF_ENTER_VALID_IP_ADDRESS' => __('Please enter a valid IP address', 'fpf-framework'),
			'FPF_LOADING' => __('Loading...', 'fpf-framework'),
			'FPF_LOADING_ANALYTICS' => __('Loading Analytics...', 'fpf-framework'),
			'FPF_INVALID_IP_ADDRESS' => __('Invalid IP Address', 'fpf-framework'),
			'FPF_DOWNLOADING_UPDATES_PLEASE_WAIT' => __('Downloading Updates. Please wait...', 'fpf-framework'),
			'FPF_DATABASE_UPDATED' => __('Database updated!', 'fpf-framework'),
			'FPF_BUTTON_LABEL' => __('Button Label', 'fpf-framework'),
			'FPF_BUTTON_CLASSES' => __('Button Classes', 'fpf-framework'),
			'FPF_PREVENT_DEFAULT_ACTION' => __('Prevent Default Action', 'fpf-framework'),
			'FPF_ANALYTICS' => __('Analytics', 'fpf-framework'),
			'FPF_DATE' => __('Date', 'fpf-framework'),
			'FPF_DATES' => __('Dates', 'fpf-framework'),
			'FPF_FILTER' => __('Filter', 'fpf-framework'),
			'FPF_COMPARE' => __('Compare', 'fpf-framework'),
			'FPF_CUSTOM' => __('Custom', 'fpf-framework'),
			'FPF_DATE_RANGE' => __('Date Range', 'fpf-framework'),
			'FPF_CANCEL' => __('Cancel', 'fpf-framework'),
			'FPF_APPLY' => __('Apply', 'fpf-framework'),
			'FPF_LEARN_MORE' => __('Learn more', 'fpf-framework'),
			'FPF_START_DATE' => __('Start Date', 'fpf-framework'),
			'FPF_END_DATE' => __('End Date', 'fpf-framework'),
			'FPF_URLS_CONTAINING' => __('URLs containing', 'fpf-framework'),
			'FPF_URLS_NOT_CONTAINING' => __('URLs not containing', 'fpf-framework'),
			'FPF_EXACT_URL' => __('Exact URL', 'fpf-framework'),
			'FPF_EXAMPLE_LINK_HINT' => __('https://www.example.com/', 'fpf-framework'),
			'FPF_SELECT_A_FILTER_TYPE' => __('Select a filter type', 'fpf-framework'),
			'FPF_SELECT_A_DEVICE' => __('Select a device', 'fpf-framework'),
			'FPF_SELECT_A_COUNTRY' => __('Select a country', 'fpf-framework'),
			'FPF_VS_LC' => __('vs', 'fpf-framework'),
			'FPF_NO_DATA' => __('No data', 'fpf-framework'),
			'FPF_IMPRESSIONS_PREVIOUS_PERIOD' => __('Impressions Previous Period', 'fpf-framework'),
			'FPF_GO_PRO' => __('Go Pro', 'fpf-framework'),
			'FPF_UNLOCK_MORE_FEATURES_WITH_PRO' => __('Unlock more features by going Pro!', 'fpf-framework'),
			'FPF_UNLOCK_MORE_FEATURES_WITH_PRO_READ_MORE' => __('Unlock more features by going Pro! Click to read all features provided in the Pro version.', 'fpf-framework'),
			'FPF_DAY' => __('Day', 'fpf-framework'),
			'FPF_WEEK' => __('Week', 'fpf-framework'),
			'FPF_MONTH' => __('Month', 'fpf-framework'),
			'FPF_DIFFERENCE' => __('Difference', 'fpf-framework'),
			'FPF_TABLE_DATA_OMITTED' => __('Table data omitted as there are no additional information to display.', 'fpf-framework'),
			'FPF_AVG_TIME_OPEN' => __('Average Time Open', 'fpf-framework'),
			'FPF_THEAVERAGETIMEOPEN' => __('Average Time Open', 'fpf-framework'),
			'FPF_THEAVERAGETIMEOPEN_PREVIOUS_PERIOD' => __('Average Time Open Previous Period', 'fpf-framework'),
			'FPF_ANALYTICS' => __('Analytics', 'fpf-framework'),
			'FPF_VIEW_MORE' => __('View More', 'fpf-framework'),
			'FPF_ADVANCED_ANALYTICS' => __('Advanced Analytics', 'fpf-framework'),
			'FPF_PLUGIN_MISSING' => __('Plugin <strong>%s</strong> is missing.', 'fpf-framework'),
			'FPF_PLUGIN_MISSING_INSTALL_TO_USE_FEATURE' => __('Plugin <strong>%s</strong> is missing. Please install it to use %s.', 'fpf-framework'),
			'FPF_ANALYZE' => __('Analyze', 'fpf-framework'),
			'FPF_PERCENTAGE_CHANGE_OVER_PREVIOUS_PERIOD' => __('Percentage change over previous period', 'fpf-framework'),
			'FPF_ANALYTICS_TABLE_NO_DATA_TO_DISPLAY' => __('There are no items to display.', 'fpf-framework'),
			'FPF_SELECT_A_PERIOD' => __('Select a period', 'fpf-framework'),
			'FPF_ANALYTICS_OVERVIEW_LOADING' => __('Loading Analytics Overview...', 'fpf-framework'),
			'FPF_REFERRER' => __('Referrer', 'fpf-framework'),
			'FPF_REFERRERS' => __('Referrers', 'fpf-framework'),
			'FPF_REFERRERS_CONTAINING' => __('Referrers containing', 'fpf-framework'),
			'FPF_REFERRERS_NOT_CONTAINING' => __('Referrers not containing', 'fpf-framework'),
			'FPF_EXACT_REFERRER' => __('Exact Referrer URL', 'fpf-framework'),
			'FPF_6_MONTHS' => __('6 Months', 'fpf-framework'),
			'FPF_1_YEAR' => __('1 Year', 'fpf-framework'),
			'FPF_2_YEARS' => __('2 Years', 'fpf-framework'),
			'FPF_3_YEARS' => __('3 Years', 'fpf-framework'),
			'FPF_TODAY' => __('Today', 'fpf-framework'),
			'FPF_DATE_PERIOD' => __('Date Period', 'fpf-framework'),
			'FPF_TOP_DEVICES' => __('Top Devices', 'fpf-framework'),
			'FPF_TOP_COUNTRIES' => __('Top Countries', 'fpf-framework'),
			'FPF_TOP_REFERRERS' => __('Top Referrers', 'fpf-framework'),
			'FPF_PM' => __('PM', 'fpf-framework'),
			'FPF_AM' => __('AM', 'fpf-framework'),
			'FPF_ANALYTICS_OVERVIEW_OVERLAY_PRO_MSG1' => __('Get a quick overview of <strong>%s</strong> from your Dashboard!', 'fpf-framework'),
			'FPF_FEATURE_IMAGE_UPGRADE_PRO_MSG1' => __('<strong>%s</strong> is a Pro feature!', 'fpf-framework'),
			'FPF_FEATURE_IMAGE_UPGRADE_PRO_MSG2' => __('Upgrade to Pro to unlock this feature.', 'fpf-framework'),
			'FPF_%S' => __('%s', 'fpf-framework'),
			'FPF_ADD_NEW' => __('Add New', 'fpf-framework'),
			'FPF_ADD_NEW_%S' => __('Add New %s', 'fpf-framework'),
			'FPF_EDIT_%S' => __('Edit %s', 'fpf-framework'),
			'FPF_NEW_%S' => __('New %s', 'fpf-framework'),
			'FPF_VIEW_%S' => __('View %s', 'fpf-framework'),
			'FPF_SEARCH' => __('Search', 'fpf-framework'),
			'FPF_SEARCH_%S' => __('Search %s', 'fpf-framework'),
			'FPF_NO_%S_FOUND' => __('No %s found', 'fpf-framework'),
			'FPF_NO_%S_FOUND_IN_TRASH' => __('No %s found in Trash', 'fpf-framework'),
			'FPF_PARENT_%S' => __('Parent %s:', 'fpf-framework'),
			'FPF_RESET' => __('Reset', 'fpf-framework'),
			'FPF_RESET_COLOR' => __('Reset color', 'fpf-framework'),
			'FPF_DEFAULT' => __('Default', 'fpf-framework'),
			'FPF_SELECT_COLOR' => __('Select color', 'fpf-framework'),
			'FPF_SELECT_DEFAULT_COLOR' => __('Select default color', 'fpf-framework'),
			'FPF_COLOR_VALUE' => __('Color value', 'fpf-framework'),
			'FPF_PHP_VERSION_FAIL' => __('%s requires PHP version %s+, please upgrade to the mentioned PHP version in order for the plugin to work.', 'fpf-framework'),
			'FPF_TEMPLATE' => __('Template', 'fpf-framework'),
			'FPF_KEEP_DATA_ON_UNINSTALL' => __('Keep data on uninstall', 'fpf-framework'),
			'FPF_KEEP_DATA_ON_UNINSTALL_DESC' => __('<strong>Enable</strong> to preserve the data when you uninstall the plugin.<br><strong>Disable</strong> to remove the data when you uninstall the plugin.', 'fpf-framework'),
			'FPF_HI' => __('Hi', 'fpf-framework'),
			'FPF_MADE_WITH_LOVE_BY_FP' => __('Made with ♥️ by FirePlugins', 'fpf-framework'),
			'FPF_GET_PRO_FEATURES' => __('Get PRO Features', 'fpf-framework'),
			'FPF_ROADMAP' => __('Roadmap', 'fpf-framework'),
			'FPF_TERMS_OF_USE' => __('Terms of Use', 'fpf-framework'),
			'FPF_PRIVACY_POLICY' => __('Privacy Policy', 'fpf-framework'),
			'FPF_WRITE_REVIEW' => __('Leave a review on WordPress Plugin Directory', 'fpf-framework'),
			'FPF_LIKE_PLUGIN' => __('Like %s?', 'fpf-framework'),
			'FPF_GO_TO_FP_SITE' => __('Go to FirePlugins Site', 'fpf-framework'),
			'FPF_MEDIA' => __('Media', 'fpf-framework'),
			'FPF_UNINSTALL' => __('Uninstall', 'fpf-framework'),
			'FPF_SETTINGS_UNINSTALL_DESC' => __('Select whether to keep or delete your settings on plugin uninstall.', 'fpf-framework'),
			'FPF_SETTINGS_LICENSE_DESC' => __('Activate your license to get automatic updates.', 'fpf-framework'),
			'FPF_DIMENSIONS_FIELD_LINK_VALUES_TITLE' => __('Enable to automatically fill in all values.', 'fpf-framework'),
			'FPF_REVIEW_REMINDER_MSG1' => __('%1$s Thank you for using our plugin, %2$s%3$s%4$s! %5$s You rock! Could you please do us a BIG favor and give it a 5-star rating on WordPress? This will help us spread the word and boost our motivation. %6$s - %7$s FirePlugins %8$s %9$s', 'fpf-framework'),
            'FPF_REVIEW_REMINDER_MSG2' => __('%1$s %2$s Yes, take me there! %3$s %4$s Remind me later %3$s %5$s I\'ve already done this  %3$s %6$s', 'fpf-framework'),
			'FPF_UNITS_TITLE' => __('Select the unit for this field.', 'fpf-framework'),
			'FPF_FORGOT_YOUR_PASSWORD' => __('Forgot your password?', 'fpf-framework'),
			'FPF_REFERRER_POPULAR_LIST_SELECTION' => __('Popular referrers', 'fpf-framework'),
			'FPF_REFERRER_POPULAR_LIST_SELECTION_DESC' => __('Select a referrer from a pre-defined list of popular referrers', 'fpf-framework'),
			'FPF_RENDER' => __('Render', 'fpf-framework'),
			'FPF_STATE' => __('State', 'fpf-framework'),
			'FPF_STATUS' => __('Status', 'fpf-framework'),
			'FPF_MISC' => __('Misc', 'fpf-framework'),
			'FPF_MISC_SETTINGS_DESC' => __('Configure miscellaneous settings in this section.', 'fpf-framework'),
			'FPF_NEVER' => __('Never', 'fpf-framework'),
			'FPF_SECONDS' => __('Seconds', 'fpf-framework'),
			'FPF_SECONDS_SHORT' => __('Secs', 'fpf-framework'),
			'FPF_MINUTES_SHORT' => __('Mins', 'fpf-framework'),
			'FPF_MINUTES' => __('Minutes', 'fpf-framework'),
			'FPF_HOURS' => __('Hours', 'fpf-framework'),
			'FPF_HOURS_SHORT' => __('Hrs', 'fpf-framework'),
			'FPF_DAYS' => __('Days', 'fpf-framework'),
			'FPF_ALWAYS_SHOW' => __('Always Show', 'fpf-framework'),
			'FPF_START_FROM_SCRATCH' => __('Start from scratch', 'fpf-framework'),
			'FPF_PREVIEW_TEMPLATE_FRONTEND' => __('Preview template in the front-end', 'fpf-framework'),
			'FPF_LIBRARY_SAVE_TEMPLATE_FAVORITES' => __('Save template to favorites', 'fpf-framework'),
			'FPF_LOADING_TEMPLATES' => __('Loading Templates...', 'fpf-framework'),
			'FPF_REFRESH_TEMPLATES' => __('Refresh Templates', 'fpf-framework'),
			'FPF_NO_RESULTS_FOUND' => __('No Results Found', 'fpf-framework'),
			'FPF_LIBRARY_NO_RESULTS_DESC' => __('Please make sure your search is spelled correctly or try different words.', 'fpf-framework'),
			'FPF_CUSTOM_SOUND_FILE' => __('Custom Sound File', 'fpf-framework'),
			'FPF_CUSTOM_SOUND_URL' => __('Custom Sound URL', 'fpf-framework'),
			'FPF_ONCE' => __('Once', 'fpf-framework'),
			'FPF_UNLIMITED' => __('Unlimited', 'fpf-framework'),
			'FPF_FREQUENCY' => __('Frequency', 'fpf-framework'),
			'FPF_SHOW' => __('Show', 'fpf-framework'),
			'FPF_DONT_SHOW_AGAIN_FOR' => __('Don\'t show again for', 'fpf-framework'),
			'FPF_TIMES_PER' => __('Times Per', 'fpf-framework'),
			'FPF_SHOW_FREQUENCY' => __('Show Frequency', 'fpf-framework'),
			'FPF_EVERY_TIME_PAGE_LOADS' => __('Every Time Page Loads', 'fpf-framework'),
			'FPF_GEO_DB_HAS_NOT_BEEN_UPDATED' => __('Database has not been updated.', 'fpf-framework'),
			'FPF_BEHAVIOR' => __('Behavior', 'fpf-framework'),
			'FPF_TEXT_POSITION' => __('Text Position', 'fpf-framework'),
			'FPF_NEW_ACTION_LABEL' => __('New Action Label', 'fpf-framework'),
			'FPF_EDIT_ITEM' => __('Edit item', 'fpf-framework'),
			'FPF_REMOVE_ITEM' => __('Remove item', 'fpf-framework'),
			'FPF_MOVE_ITEM' => __('Reorder item', 'fpf-framework'),
			'FPF_ACTIVATE_LICENSE' => __('Activate License', 'fpf-framework'),
			'FPF_DEACTIVATE_LICENSE' => __('Deactivate License', 'fpf-framework'),
			'FPF_YOUR_CURRENT_VERSION_IS_X' => __('Your current version is %s.', 'fpf-framework'),
			'FPF_X_VERSION_IS_AVAILABLE' => __('%s is available!', 'fpf-framework'),
			'FPF_VIEW_CHANGELOG' => __('View Changelog', 'fpf-framework'),
			'FPF_UPDATE' => __('Update', 'fpf-framework'),
			'FPF_PRO_TEMPLATES' => __('Pro Templates', 'fpf-framework'),
			'FPF_TEMPLATES_CANNOT_BE_RETRIEVED' => __('Cannot retrieve templates.', 'fpf-framework'),
			'FPF_HIDE_PRO_TEMPLATES' => __('Hide Pro Templates', 'fpf-framework'),
			'FPF_ENTER_LICENSE_TO_USE_TEMPLATE' => __('To start using this template, please enter your license and refresh templates.', 'fpf-framework'),
			'FPF_ENJOY' => __('Enjoy', 'fpf-framework'),
			'FPF_NO_LICENSE_NEEDED' => __('No license needed', 'fpf-framework'),
			'FPF_VALID' => __('valid', 'fpf-framework'),
			'FPF_INVALID' => __('invalid', 'fpf-framework'),
			'FPF_YOUR_LICENSE_KEY_IS_STATUS' => __('Your license key is <strong class="fpf-%s-color">%s</strong>.', 'fpf-framework'),
			'FPF_PLEASE_ENTER_A_VALID_LICENSE_KEY_TO_RECEIVE_UPDATES' => __('Please enter a valid license key to receive updates.', 'fpf-framework'),
			'FPF_ARE_YOU_SURE_YOU_WANT_TO_DELETE_THIS_ITEM' => __('Are you sure you want to delete this item?', 'fpf-framework'),
			'FPF_STAR' => __('Star', 'fpf-framework'),
			'FPF_AND' => __('and', 'fpf-framework'),
		];
	}
}